@@ -3,7 +3,4 @@
 from .application_tester import ApplicationTester
 from .command_tester import CommandTester
 
-__all__ = [
-    'ApplicationTester',
-    'CommandTester'
-]
+__all__ = ["ApplicationTester", "CommandTester"]
